"use strict";
const common_vendor = require("../../common/vendor.js");
const _sfc_main = {
  data() {
    return {
      account: "",
      password: "",
      confirmPassword: "",
      smsCode: "",
      showPassword: false,
      agreed: false,
      useSmsCode: false,
      countdown: 0
    };
  },
  computed: {
    canSubmit() {
      return this.account && this.password && this.confirmPassword && this.agreed && (!this.useSmsCode || this.smsCode);
    }
  },
  methods: {
    toggleAgreement(e) {
      this.agreed = e.detail.value.length > 0;
    },
    getSmsCode() {
      if (!this.account) {
        common_vendor.index.showToast({
          title: "请输入手机号",
          icon: "none"
        });
        return;
      }
      this.countdown = 60;
      const timer = setInterval(() => {
        this.countdown--;
        if (this.countdown <= 0) {
          clearInterval(timer);
        }
      }, 1e3);
    },
    validateForm() {
      if (this.password.length < 6 || this.password.length > 20) {
        common_vendor.index.showToast({
          title: "密码长度需为6-20位",
          icon: "none"
        });
        return false;
      }
      if (this.password !== this.confirmPassword) {
        common_vendor.index.showToast({
          title: "两次输入的密码不一致",
          icon: "none"
        });
        return false;
      }
      return true;
    },
    async handleRegister() {
      if (!this.validateForm())
        return;
      try {
        const res = await this.$api.auth.register({
          account: this.account,
          password: this.password,
          code: this.useSmsCode ? this.smsCode : void 0
        });
        common_vendor.index.showToast({
          title: "注册成功",
          icon: "success"
        });
      } catch (error) {
        common_vendor.index.showToast({
          title: error.message || "注册失败",
          icon: "none"
        });
      }
    },
    goToLogin() {
      common_vendor.index.navigateTo({
        url: "/pages/auth/login"
      });
    }
  }
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: $data.account,
    b: common_vendor.o(($event) => $data.account = $event.detail.value),
    c: $data.showPassword ? "text" : "password",
    d: $data.password,
    e: common_vendor.o(($event) => $data.password = $event.detail.value),
    f: common_vendor.t($data.showPassword ? "隐藏" : "显示"),
    g: common_vendor.o(($event) => $data.showPassword = !$data.showPassword),
    h: $data.confirmPassword,
    i: common_vendor.o(($event) => $data.confirmPassword = $event.detail.value),
    j: $data.useSmsCode
  }, $data.useSmsCode ? {
    k: $data.smsCode,
    l: common_vendor.o(($event) => $data.smsCode = $event.detail.value),
    m: common_vendor.t($data.countdown > 0 ? `${$data.countdown}s后重试` : "获取验证码"),
    n: $data.countdown > 0,
    o: common_vendor.o((...args) => $options.getSmsCode && $options.getSmsCode(...args))
  } : {}, {
    p: $data.agreed,
    q: common_vendor.o((...args) => $options.toggleAgreement && $options.toggleAgreement(...args)),
    r: !$options.canSubmit,
    s: common_vendor.o((...args) => $options.handleRegister && $options.handleRegister(...args)),
    t: common_vendor.o((...args) => $options.goToLogin && $options.goToLogin(...args))
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render], ["__scopeId", "data-v-4bb68961"]]);
wx.createPage(MiniProgramPage);
//# sourceMappingURL=../../../.sourcemap/mp-weixin/pages/auth/register.js.map
